/*
htop
(C) 2004 Hisham H. Muhammad
Released under the GNU GPL, see the COPYING file
in the source distribution for its full text.
*/

#include "StringList.h"
#include "Vector.h"
#include "String.h"
#include <stdio.h>

/*{
typedef struct StringList_ {
   Vector* vector;
} StringList;
}*/

StringList* StringList_new() {
   StringList* s;
   
   s = (StringList*) malloc(sizeof(StringList));
   s->vector = Vector_new();
   Vector_setCompareFunction(s->vector, StringList_compareFunction);
   return s;
}

StringList* StringList_clone(StringList* s) {
   StringList* clone;
   int i;
   
   clone = StringList_new();
   for (i = 0; i < s->vector->items; i++)
      StringList_add(clone, s->vector->array[i]);
   return clone;
}

int StringList_compareFunction(void* a, void* b) {
   return strcmp((char*)a, (char*)b);
}

void StringList_prune(StringList* s) {
   Vector_prune(s->vector);
}

void StringList_delete(StringList* s) {
   Vector_delete(s->vector);
   free(s);
}

int StringList_size(StringList* s) {
   return Vector_size(s->vector);
}

int StringList_indexOf(StringList* s, char* search) {
   return Vector_indexOf(s->vector, search);
}

void StringList_set(StringList* s, int index, char* data) {
   Vector_set(s->vector, index, String_copy(data));
}

char* StringList_getRef(StringList* s, int index) {
   return (char*) Vector_get(s->vector, index);
}

char* StringList_get(StringList* s, int index) {
   char* get;
   get = (char*) Vector_get(s->vector, index);
   if (get != NULL) {
      return String_copy(get);
   }
   return NULL;
}

void StringList_add(StringList* s, char* data) {
   Vector_add(s->vector, String_copy(data));
}

void StringList_print(StringList* s) {
   int i;
   for (i = 0; i < s->vector->items; i++)
      printf("'%s'\n", (char*) s->vector->array[i]);
}
