/*
htop
(C) 2004 Hisham H. Muhammad
Released under the GNU GPL, see the COPYING file
in the source distribution for its full text.
*/

#include "UsersTable.h"
#include "Hashtable.h"
#include "String.h"

#include <stdio.h>
#include <strings.h>
#include <assert.h>

/*{
#ifndef SYSCONFDIR
#define SYSCONFDIR "/etc"
#endif
}*/

/*{
typedef struct UsersTable_ {
   Hashtable* users;
} UsersTable;
}*/

UsersTable* UsersTable_new() {
   UsersTable* this;
   this = malloc(sizeof(UsersTable));
   this->users = Hashtable_new(20);
   return this;
}

void UsersTable_delete(UsersTable* this) {
   Hashtable_delete(this->users);
   free(this);
}

char* UsersTable_getRef(UsersTable* this, int uid) {
   return (char*) (Hashtable_get(this->users, uid));
}

int UsersTable_size(UsersTable* this) {
   return (Hashtable_size(this->users));
}

void UsersTable_scan(UsersTable* this) {
   Hashtable_delete(this->users);
   this->users = Hashtable_new(20);
   char* passwdName = SYSCONFDIR "/passwd";
   FILE* passwd = fopen(passwdName, "r");
   assert(passwd != NULL);
   const int MAX_LINE = 256;
   char* line = malloc(MAX_LINE + 1);
   char* savedLine = line;
   while (!feof(passwd)) {
      line = savedLine;
      fgets(line, MAX_LINE, passwd);
      if (index(line, ':')) {
         char* name = String_copyUpTo(line, ':');
         line = index(line, ':') + 1;
         // skip password field
         line = index(line, ':') + 1;
         char* uidString = String_copyUpTo(line, ':');
         int uid = atoi(uidString);
         free(uidString);
         Hashtable_put(this->users, uid, name);
      }
   }
   free(savedLine);
   fclose(passwd);
}
